# hydenv-database
Multi-origin multi-purpose database management tools for the database lecture

## Install

You can install all tools at once using a Python > 3.5 with pip:

```bash
pip install hydenv
```

## Docs

~Documentation can be found here: https://data-hydenv.github.io/hydenv-database~
This will be replaced at some point
